Package: baseballstats
Type: Package
Title: Compute basic baseball statistics
Version: 0.1
Author: Uptake Data Science
Authors@R: c(
    person("James", "Lamb", email = "jaylamb20@gmail.com", role = c("aut", "cre")),
    person("Brian", "Burns", email = "brian.burns.opensource@gmail.com", role = c("aut")))
Maintainer: James Lamb <james.lamb@uptake.com>
Description: This package is used to test the functions in `pkgnet`.
Imports:
    base,
    methods,
    utils
Suggests:
    covr,
    testthat
License: file LICENSE
LazyData: TRUE
RoxygenNote: 7.3.1
