# Generated by roxygen2: do not edit by hand

export(Five)
export(Four)
export(One)
export(PoohAnsuh)
export(RightAnswer)
export(Six)
export(Three)
export(Two)
exportClasses(PoohAnswer)
exportClasses(RightAnswer)
importFrom(R6,R6Class)
