# Generated by roxygen2: do not edit by hand

export(CreatePackageReport)
export(CreatePackageVignette)
export(DefaultReporters)
export(DependencyReporter)
export(FunctionReporter)
export(InheritanceReporter)
export(PackageReport)
export(SummaryReporter)
import(data.table)
importFrom(DT,datatable)
importFrom(DT,formatRound)
importFrom(R6,R6Class)
importFrom(R6,is.R6)
importFrom(R6,is.R6Class)
importFrom(assertthat,assert_that)
importFrom(assertthat,is.flag)
importFrom(assertthat,is.readable)
importFrom(assertthat,is.string)
importFrom(assertthat,is.writeable)
importFrom(covr,package_coverage)
importFrom(data.table,":=")
importFrom(data.table,as.data.table)
importFrom(data.table,copy)
importFrom(data.table,data.table)
importFrom(data.table,rbindlist)
importFrom(data.table,setkeyv)
importFrom(glue,glue)
importFrom(grDevices,colorRamp)
importFrom(grDevices,colorRampPalette)
importFrom(grDevices,rgb)
importFrom(igraph,V)
importFrom(igraph,betweenness)
importFrom(igraph,centr_betw_tmax)
importFrom(igraph,centr_clo_tmax)
importFrom(igraph,centr_degree_tmax)
importFrom(igraph,centralize)
importFrom(igraph,closeness)
importFrom(igraph,degree)
importFrom(igraph,ego_size)
importFrom(igraph,graph_from_edgelist)
importFrom(igraph,hits_scores)
importFrom(igraph,make_empty_graph)
importFrom(igraph,page_rank)
importFrom(igraph,vcount)
importFrom(igraph,vertex)
importFrom(knitr,knit_child)
importFrom(knitr,opts_chunk)
importFrom(magrittr,"%>%")
importFrom(methods,is)
importFrom(rlang,enexpr)
importFrom(rmarkdown,render)
importFrom(tools,file_ext)
importFrom(tools,file_path_as_absolute)
importFrom(tools,package_dependencies)
importFrom(utils,browseURL)
importFrom(utils,installed.packages)
importFrom(utils,packageDescription)
importFrom(visNetwork,visEdges)
importFrom(visNetwork,visHierarchicalLayout)
importFrom(visNetwork,visIgraphLayout)
importFrom(visNetwork,visNetwork)
importFrom(visNetwork,visOptions)
