---
title: "Package Dependency Report"
output: html_document
---

## Dependency Network

This section analyzes the recursive package dependencies of **`r reporter$pkg_name`**. 

In the plot below, you'll see the following colors:

- orange: **`r reporter$pkg_name`**
- gray: R packages available [in every R session by default](https://cran.r-project.org/doc/manuals/r-release/R-admin.html#Default-packages)
- green: third-party R packages

```{r echo = FALSE, error = TRUE}
reporter$calculate_default_measures()
```

### Visualization

Nodes are packages. Edges point in the direction of dependence.

```{r echo = FALSE, error = TRUE}
reporter$graph_viz
```

### Table

```{r error = TRUE}
reporter$get_summary_view()
```
