---
title: "Package Function Report"
output: html_document
---

## Function Network

This section analyzes the dependency relationships between functions within **`r reporter$pkg_name`**. 

```{r echo = FALSE, error = TRUE}
reporter$calculate_default_measures()
```

### Visualization

Nodes are functions. Edges point in the direction of dependence.

```{r echo = FALSE, error = TRUE}
reporter$graph_viz
```

### Table

```{r error = TRUE}
reporter$get_summary_view()
```
