---
title: "{{pkg_name}} Package Report, by pkgnet"
output: 
    rmarkdown::html_vignette:
        toc: true
vignette: >
    %\VignetteIndexEntry{ {{pkg_name}} Package Report, by pkgnet }
    %\VignetteEngine{knitr::rmarkdown}
    %\VignetteEncoding{UTF-8}
---

This report on **{{pkg_name}}** is generated by [**pkgnet**](https://uptakeopensource.github.io/pkgnet/), an R package for analyzing other R packages through the lens of [network theory](https://en.wikipedia.org/wiki/Network_theory). 

```{r setup, include=FALSE}
library(pkgnet)

knitr::opts_chunk$set(
    echo = FALSE
    , warning=FALSE
    , out.width='100%'
)
pkgnet:::silence_logger()

reporters <- {{pkg_reporters}}

reporters <- lapply(
          X = reporters
          , FUN = function(reporter){
              reporter$set_package(pkg_name = "{{pkg_name}}")
              return(reporter)
          }
      )

```

```{r warning=FALSE}
reportSections <- lapply(reporters, function(reporter) {
  report_env <- list2env(list(reporter = reporter))
  knitr::knit_child(
    reporter$report_markdown_path
    , envir = report_env
  )
})

```

```{r results="asis"}
cat(paste0(paste(reportSections, collapse = '\n')))
```

---

```{r results="asis"}
cat(sprintf("<sup>This report built with **pkgnet v%s**.</sup>", packageVersion('pkgnet')))
```

<sup>[**pkgnet**](https://uptakeopensource.github.io/pkgnet/) is an open-source R package, copyright &copy; 2017-2019 Uptake, made available under the 3-Clause BSD License.</sup>

```{r echo = FALSE}
pkgnet:::unsilence_logger()
```
