% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/The_Friend.R
\docType{class}
\name{PoohAnswer}
\alias{PoohAnswer}
\alias{PoohAnsuh}
\title{Pooh's Answer}
\description{
Pooh's Answer to a Question
}

\seealso{
Other TheFriend: 
\code{\link{RightAnswer}}
}
\concept{TheFriend}
