% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/The_Friend.R
\docType{class}
\name{RightAnswer}
\alias{RightAnswer}
\title{Right Answer}
\description{
Correct Answer to a Question
}

\seealso{
Other TheFriend: 
\code{\link{PoohAnswer}}
}
\concept{TheFriend}
