% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/self_control.R
\name{take_a_break}
\alias{take_a_break}
\title{Take a Break}
\usage{
take_a_break()
}
\description{
Test if .parse_function() breaks with control function 'break'
}
