% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Being_and_Nothingness.R
\name{somethingAboutNothing}
\alias{somethingAboutNothing}
\title{nothing}
\usage{
somethingAboutNothing()
}
\value{
nothingness
}
\description{
nothing
}
\examples{
\dontrun{NULL}
}
