% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/self_control.R
\name{next_up}
\alias{next_up}
\title{Next Up}
\usage{
next_up()
}
\description{
Test if .parse_function() breaks with control function 'next'
}
